package com.da.dangan.mapper;

import com.da.dangan.domain.DaCzrkdj;

import java.util.List;

/**
 * 常住人口登记Mapper接口
 * 
 * @author hs
 * @date 2024-05-08
 */
public interface DaCzrkdjMapper 
{
    /**
     * 查询常住人口登记
     * 
     * @param id 常住人口登记主键
     * @return 常住人口登记
     */
    public DaCzrkdj selectDaCzrkdjById(Long id);

    /**
     * 查询常住人口登记列表
     * 
     * @param daCzrkdj 常住人口登记
     * @return 常住人口登记集合
     */
    public List<DaCzrkdj> selectDaCzrkdjList(DaCzrkdj daCzrkdj);

    /**
     * 新增常住人口登记
     * 
     * @param daCzrkdj 常住人口登记
     * @return 结果
     */
    public int insertDaCzrkdj(DaCzrkdj daCzrkdj);

    /**
     * 修改常住人口登记
     * 
     * @param daCzrkdj 常住人口登记
     * @return 结果
     */
    public int updateDaCzrkdj(DaCzrkdj daCzrkdj);

    /**
     * 删除常住人口登记
     * 
     * @param id 常住人口登记主键
     * @return 结果
     */
    public int deleteDaCzrkdjById(Long id);

    /**
     * 批量删除常住人口登记
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDaCzrkdjByIds(Long[] ids);
}
